@@ -14,11 +14,9 @@ import allure
 import numpy as np
 import pytest
 from PIL import Image
-from selenium.common import WebDriverException, NoSuchDriverException, InvalidSessionIdException, \
+from selenium.common import NoSuchDriverException, InvalidSessionIdException, \
     StaleElementReferenceException
 
-from shadowstep.exceptions.shadowstep_exceptions import ShadowstepException
-
 T = TypeVar("T", bound=Callable[..., Any])
 
 DEFAULT_EXCEPTIONS: Tuple[Type[Exception], ...] = (
@@ -27,24 +25,14 @@ DEFAULT_EXCEPTIONS: Tuple[Type[Exception], ...] = (
     StaleElementReferenceException,
 )
 
-import time
-import functools
-import traceback
-from typing import Callable, Any, Optional, Tuple, Type
-
-DEFAULT_EXCEPTIONS: Tuple[Type[Exception], ...] = (
-    NoSuchDriverException,
-    InvalidSessionIdException,
-    StaleElementReferenceException,
-)
 
 def fail_safe(
-    retries: int = 3,
-    delay: float = 0.5,
-    raise_exception: Optional[Type[Exception]] = None,
-    fallback: Any = None,
-    exceptions: Tuple[Type[Exception], ...] = DEFAULT_EXCEPTIONS,
-    log_args: bool = False,
+        retries: int = 3,
+        delay: float = 0.5,
+        raise_exception: Optional[Type[Exception]] = None,
+        fallback: Any = None,
+        exceptions: Tuple[Type[Exception], ...] = DEFAULT_EXCEPTIONS,
+        log_args: bool = False,
 ) -> Callable:
     """
     Decorator that retries a method call on specified exceptions.
@@ -77,6 +65,7 @@ def fail_safe(
        - If raise_exception is set, raises it.
        - Otherwise, returns fallback (None by default).
     """
+
     def decorator(func: Callable) -> Callable:
         @functools.wraps(func)
         def wrapper(self, *args, **kwargs):
@@ -84,6 +73,10 @@ def fail_safe(
 
             for attempt in range(1, retries + 2):
                 try:
+                    if hasattr(self, "base") and hasattr(self.base, "is_connected"):
+                        if not self.base.is_connected():
+                            self.logger.warning(f"[fail_safe] No session before {func.__name__}(), reconnecting")
+                            self.base.reconnect()
                     return func(self, *args, **kwargs)
                 except exceptions as e:
                     last_exc = e
@@ -113,10 +106,11 @@ def fail_safe(
                     stack = "".join(traceback.format_stack(limit=5))
                     self.logger.debug(f"[fail_safe] stack:\n{stack}")
 
-                    # Attempt to reconnect; if it fails, let the error propagate
-                    if hasattr(self, "base") and hasattr(self.base, "reconnect"):
-                        self.logger.debug("[fail_safe] Calling self.base.reconnect()")
-                        self.base.reconnect()
+                    if hasattr(self, "base") and hasattr(self.base, "is_connected"):
+                        if not self.base.is_connected():
+                            self.logger.warning(
+                                f"[fail_safe] Disconnected after exception in {method}, reconnecting...")
+                            self.base.reconnect()
 
                     # Wait before the next retry if any remain
                     if attempt <= retries:
@@ -144,8 +138,6 @@ def fail_safe(
     return decorator
 
 
-
-
 def retry(func):
     """
     Повторяет выполнение метода если он возвращает False или None.
@@ -753,10 +745,3 @@ def _get_screenshot_bytes(self) -> bytes:
 
         # Возвращаем байты изображения
         return byte_io.getvalue()
-
-
-
-
-
-
-
